using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.Ink;
using System.Diagnostics;
using System.IO;
using System.Xml;



namespace JournalBrowser {
    public partial class Form1 : Form {

        JournalDocument journalDocument;

        InkCollector myInkCollector;

        public Form1() {
            InitializeComponent();
            this.myInkCollector = new InkCollector(this.splitContainer1.Panel1.Handle);
            this.myInkCollector.Enabled = true;
        }

        private void OnOpenClick(object sender, EventArgs e) {
            Stream jntStream = null;
            Stream xmlStream = null;
            OpenFileDialog openFileDialog1 = new OpenFileDialog();

            // Get the filename from the user by using a File Open dialog

            openFileDialog1.Filter =
              "Journal files (*.jnt)|*.jnt|All files (*.*)|*.*";
            openFileDialog1.FilterIndex = 1;
            openFileDialog1.RestoreDirectory = true;

            if (openFileDialog1.ShowDialog() == DialogResult.OK) {
                try {
                    if ((jntStream = openFileDialog1.OpenFile()) != null) {
                        // Read in the Journal file
                        xmlStream = JournalReader.ReadFromStream(jntStream);

                        // Display results
                        this.journalDocument = new JournalDocument(xmlStream);
                        this.mainTextBox.Text = TextSummary(this.journalDocument);
                        this.myInkCollector.Enabled = false;
                        this.myInkCollector.Ink = this.journalDocument.GetInk(0);
                        this.myInkCollector.Enabled = false;
                        this.splitContainer1.Panel1.Refresh();
                    }
                }
                catch (System.Exception ex) {
                    Debug.WriteLine(ex.Message);
                }
                finally {
                    // Clean up
                    if (xmlStream != null)
                        xmlStream.Close();
                    if (jntStream != null)
                        jntStream.Close();
                }
            }
        }

        String TextSummary(JournalDocument journalDocument) {
            StringBuilder stringBuilder = new StringBuilder();

            stringBuilder.Append("Journal Document \r\n" + "Pages: " + journalDocument.PageCount + "\r\n");

            foreach (JournalPage page in journalDocument.Pages) {
                stringBuilder.Append(page.ToString() + "\r\n");
            }

            return stringBuilder.ToString();
        }


    }
}